@@ -22,19 +22,34 @@
 #' a + b
 #' a * b
 #' a / b
-#' a <- make_unit("kg m-3") # not understood by R as a division, but understood by udunits2
+#' a <- as_units("kg m-3")
 #' b <- set_units(1, kg/m/m/m)
 #' a + b
+#' a = set_units(1:5, m)
+#' a %/% a
+#' a %/% set_units(2)
+#' set_units(1:5, m^2) %/% set_units(2, m)
+#' a %% a
+#' a %% set_units(2 )
 Ops.units <- function(e1, e2) {
-  if (nargs() == 1)
-    stop(paste("unary", .Generic, "not defined for \"units\" objects"))
-  
-  eq  <- .Generic %in% c("+", "-", "==", "!=", "<", ">", "<=", ">=") # pm/equality-type
-  prd <- .Generic %in% c("*", "/")                                   # product-type
+
+  unary = nargs() == 1
+  eq  <- .Generic %in% c("+", "-", "==", "!=", "<", ">", "<=", ">=") # requiring identical units
+  prd <- .Generic %in% c("*", "/", "%/%")                            # product-type
   pw  <- .Generic %in% c( "**", "^")                                 # power-type
+  mod <- .Generic == "%%"                                            # modulo
   pm  <- .Generic %in% c("+", "-")                                   # addition-type
+
+  if (unary) {
+    if (! (.Generic %in% c("+", "-")))
+      stop("only unary + and - supported")
+    if (.Generic == "-")
+      return(e1 * set_units(-1.0))
+	else
+      return(e1)
+  }
   
-  if (! any(eq, prd, pw))
+  if (! any(eq, prd, pw, mod))
     stop(paste("operation", .Generic, "not allowed"))
   
   if (eq) {
@@ -45,10 +60,10 @@ Ops.units <- function(e1, e2) {
   
   if (prd) {
     if (! inherits(e1, "units"))
-      units(e1) = unitless
+      e1 = set_units(e1) # TODO: or warn?
 
     if (! inherits(e2, "units"))
-      units(e2) = unitless
+      e2 = set_units(e2) # TODO: or warn?
 
     if (.Generic == "*") {
       e1 <- .multiply_symbolic_units(unclass(e1), units(e1), units(e2))
@@ -60,6 +75,10 @@ Ops.units <- function(e1, e2) {
     u <- units(e1)
 
   } else if (pw) { # FIXME: I am not sure how to take powers of non-integers yet
+
+    if (identical(units(e1), set_units(1)))
+      return(set_units(unclass(e1) ^ e2, set_units(1)))
+
     if (inherits(e2, "units") || length(e2) > 1L)
       stop("power operation only allowed with length-one numeric power")
     # if (round(e2) != e2)
@@ -70,7 +89,7 @@ Ops.units <- function(e1, e2) {
     # when the power is negative and we have a special case when it is zero where
     # units should be removed.
     if (e2 == 0)
-      u <- unitless
+      u <- set_units(1)
     # else if (e2 > 0)
     #   u <- .symbolic_units(rep(units(e1)$numerator, e2),
     #                                        rep(units(e1)$denominator, e2))
@@ -90,8 +109,8 @@ Ops.units <- function(e1, e2) {
     } else { # -1 < e2 < 0 || 0 < e2 < 1
       if ((1/e2) %% 1 != 0) {
         stop("not a integer divisor")} # work on wording
-      if (any((table(units(e1)$denominator)*e2) %% 1 != 0) | 
-          any((table(units(e1)$numerator)*e2) %% 1 != 0)) {
+      if (any((table(units(e1)$denominator)*e2) %% 1 != 0) ||
+          any((table(units(e1)$numerator)*e2)   %% 1 != 0)) {
             stop("units not divisible")} # work on wording
       if (e2 > 0) # 0 < e2 < 1
         u <- .symbolic_units(
@@ -102,7 +121,7 @@ Ops.units <- function(e1, e2) {
           rep(unique(units(e1)$denominator),table(units(e1)$denominator)*abs(e2)),
           rep(unique(units(e1)$numerator),table(units(e1)$numerator)*abs(e2)))
     }
-  } else # eq, plus/minus:
+  } else # eq, plus/minus, mod:
     u <- units(e1)
 
   if (eq && !pm) {
@@ -111,3 +130,35 @@ Ops.units <- function(e1, e2) {
   } else
     .as.units(NextMethod(), u)
 }
+
+#' matrix multiplication
+#' @name matmult
+#' @param x numeric matrix or vector
+#' @param y numeric matrix or vector
+#' @export
+#' @details see \code{"\link[base]{\%*\%}"} for the base function, reimplemented
+#'   as default method
+`%*%` = function(x, y) UseMethod("%*%")
+
+#' @name matmult
+#' @export
+`%*%.default` = function(x, y) {
+	if (inherits(y, "units"))
+		`%*%.units`(x, y)
+	else
+		base::`%*%`(x, y)
+}
+
+#' @name matmult
+#' @export
+#' @examples
+#' a = set_units(1:5, m)
+#' a %*% a
+#' a %*% t(a)
+#' a %*% set_units(1:5, 1)
+#' set_units(1:5, 1) %*% a
+`%*%.units` = function(x, y) {
+	ret = `%*%.default`(unclass(x), unclass(y))
+	units(ret) = .multiply_symbolic_units(1, units(x), units(y))
+	ret
+}
