@@ -2,7 +2,7 @@ context("Unit summaries")
 
 test_that("we can compute summary functions on units", {
   x <- 1:4
-  ux <- x * make_unit("m")
+  ux <- x * as_units("m")
   
   expect_equal(as.numeric(sum(ux)), sum(x))
   expect_equal(as.numeric(min(ux)), min(x))
@@ -18,7 +18,7 @@ test_that("we can compute summary functions on units", {
   expect_error(sum(ux, x))
   
   y <- 1:4
-  uy <- y * make_unit("km")
+  uy <- y * as_units("km")
   expect_equal(as.numeric(sum(ux, uy)), sum(c(x, 1000*y)))
   expect_equal(as.numeric(min(ux, uy)), min(c(x, 1000*y)))
   expect_equal(as.numeric(max(ux, uy)), max(c(x, 1000*y)))
@@ -29,7 +29,7 @@ test_that("we can compute summary functions on units", {
 
 test_that("we can compute means and medians and quantiles", {
   x <- 1:4
-  ux <- x * make_unit("m")
+  ux <- x * as_units("m")
   w <- x / 5:8
   
   expect_equal(as.numeric(mean(ux)), mean(x))
@@ -40,11 +40,11 @@ test_that("we can compute means and medians and quantiles", {
 
 test_that("we can format units", {
   x <- 1:4
-  ux <- x * make_unit("m")
+  ux <- x * as_units("m")
   
   expect_equal(format(ux), paste(x, units(ux)))
 })
 test_that("summary works with NA values", {
-  x <- c(1, NA) * make_unit("g")
+  x <- c(1, NA) * as_units("g")
   expect_equal(summary(x), summary(as.numeric(x)))
 })
